@@ -66,7 +66,7 @@ class ConvClient:
       return str(s)
 
     def BinToOct(num):
-      l = len(num)
+      l = len(str(num))
 
       len_left = l
 
@@ -86,7 +86,7 @@ class ConvClient:
       return str(octal)
 
     def BinToHex(num):
-      l = len(num)
+      l = len(str(num))
 
       len_left = l
 
@@ -107,7 +107,7 @@ class ConvClient:
 
     #Decimal Conversions
     def DecToBin(num):
-      dec =  int(num)
+      dec = int(num)
       binn = ""
       while dec>1:
         x = dec%2
